This is the mail archive of the java-patches@gcc.gnu.org mailing list for the Java project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

FYI: Patch: classpath documentation merge


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Hi list,


I commited the attached patch to trunk to merge classpath 
documentation fixes to libgcj.


Michael
- -- 
Homepage: http://www.worldforge.org/
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.2.1 (GNU/Linux)

iD8DBQE+0KxpWSOgCCdjSDsRAhHPAJ9/CtkV+Cf4+ik0wk7YwfDCWLlMVgCdGZWM
pZfvzHawAuOpZaGRFWU3fpc=
=8jRv
-----END PGP SIGNATURE-----
Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/libjava/ChangeLog,v
retrieving revision 1.1905
diff -u -b -B -r1.1905 ChangeLog
--- ChangeLog	25 May 2003 11:24:27 -0000	1.1905
+++ ChangeLog	25 May 2003 11:28:32 -0000
@@ -1,5 +1,20 @@
 2003-05-25  Michael Koch  <konqueror@gmx.de>
 
+	* java/io/PushbackInputStream.java,
+	java/net/Authenticator.java,
+	java/net/ContentHandler.java,
+	java/net/ContentHandlerFactory.java,
+	java/net/DatagramSocket.java,
+	java/net/DatagramSocketImpl.java,
+	java/net/DatagramSocketImplFactory.java,
+	java/net/FileNameMap.java,
+	java/net/SocketImplFactory.java,
+	java/net/SocketOptions.java,
+	java/net/URLStreamHandlerFactory.java:
+	Merged new versions from classpath.
+
+2003-05-25  Michael Koch  <konqueror@gmx.de>
+
 	* java/awt/Checkbox.java,
 	java/awt/Dialog.java,
 	java/awt/Font.java,
Index: java/io/PushbackInputStream.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/io/PushbackInputStream.java,v
retrieving revision 1.8
diff -u -b -B -r1.8 PushbackInputStream.java
--- java/io/PushbackInputStream.java	15 Jun 2002 18:59:15 -0000	1.8
+++ java/io/PushbackInputStream.java	25 May 2003 11:28:32 -0000
@@ -74,8 +74,8 @@
 
   /**
    * This method initializes a <code>PushbackInputStream</code> to
-   * read from the * specified subordinate <code>InputStream</code>
-   * with a default pushback buffer * size of 1.
+   * read from the specified subordinate <code>InputStream</code>
+   * with a default pushback buffer size of 1.
    *
    * @param in The subordinate stream to read from
    */
@@ -302,7 +302,7 @@
    * <code>skip</code> method on the underlying <code>InputStream</code> to 
    * skip additional bytes if necessary.
    *
-   * @param num_bytes The requested number of bytes to skip
+   * @param numBytes The requested number of bytes to skip
    *
    * @return The actual number of bytes skipped.
    *
Index: java/net/Authenticator.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/Authenticator.java,v
retrieving revision 1.5
diff -u -b -B -r1.5 Authenticator.java
--- java/net/Authenticator.java	28 Aug 2002 05:24:10 -0000	1.5
+++ java/net/Authenticator.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* Authenticator.java -- Abstract class for obtaining authentication info
-   Copyright (C) 1998,2000 Free Software Foundation, Inc.
+   Copyright (C) 1998, 2000, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -43,12 +43,13 @@
   * some network operations (such as hitting a password protected
   * web site).
   * <p>
-  * To make use of this feature, a programmer must create a subclass of
-  * Authenticator that knows how to obtain the necessary info.  An example
+  * To make use of this feature, a programmer must create a subclass 
+  * that knows how to obtain the necessary info.  An example
   * would be a class that popped up a dialog box to prompt the user.  
-  * After creating an instance of that subclass, the static setDefault
-  * method of this class is called to set up that instance as the object
-  * to use on subsequent calls to obtain authorization.
+  * After creating an instance of that subclass, the static 
+  * <code>setDefault</code> method of this class is called to set up 
+  * that instance as the object to use on subsequent calls to obtain 
+  * authorization.
   *
   * @since 1.2
   *
@@ -57,86 +58,76 @@
   */
 public abstract class Authenticator
 {
-
-/*************************************************************************/
-
-/*
+  /*
  * Class Variables
  */
 
-/**
+  /**
   * This is the default Authenticator object to use for password requests
   */
-private static Authenticator default_authenticator;
-
-/*************************************************************************/
+  private static Authenticator defaultAuthenticator;
 
-/*
+  /*
  * Instance Variables
  */
 
-/**
+  /**
   * The hostname of the site requesting authentication
   */
-private String host;
+  private String host;
 
-/**
+  /**
   * InternetAddress of the site requesting authentication
   */
-private InetAddress addr;
+  private InetAddress addr;
 
-/**
+  /**
   * The port number of the site requesting authentication
   */
-private int port;
+  private int port;
 
-/**
+  /**
   * The protocol name of the site requesting authentication
   */
-private String protocol;
+  private String protocol;
 
-/**
+  /**
   * The prompt to display to the user when requesting authentication info
   */
-private String prompt;
+  private String prompt;
 
-/**
+  /**
   * The authentication scheme in use
   */
-private String scheme;
+  private String scheme;
 
-/*************************************************************************/
-
-/*
+  /*
  * Class Methods
  */
 
-/**
+  /**
   * This method sets the default <code>Authenticator</code> object (an 
-  * instance of a
-  * subclass of <code>Authenticator</code>) to use when prompting the user for
+    * instance of a subclass of <code>Authenticator</code>) to use when 
+    * prompting the user for
   * information.  Note that this method checks to see if the caller is
   * allowed to set this value (the "setDefaultAuthenticator" permission)
   * and throws a <code>SecurityException</code> if it is not.
   *
-  * @param def_auth The new default <code>Authenticator</code> object to use
+    * @param defAuth The new default <code>Authenticator</code> object to use
   *
   * @exception SecurityException If the caller does not have permission 
   * to perform this operation
   */ 
-public static void
-setDefault(Authenticator def_auth)
-{
+  public static void setDefault(Authenticator defAuth)
+  {
   SecurityManager sm = System.getSecurityManager();
   if (sm != null)
     sm.checkPermission(new NetPermission("setDefaultAuthenticator"));
 
-  default_authenticator = def_auth;
-} 
+    defaultAuthenticator = defAuth;
+  } 
 
-/*************************************************************************/
-
-/**
+  /**
   * This method is called whenever a username and password for a given
   * network operation is required.  First, a security check is made to see
   * if the caller has the "requestPasswordAuthentication"
@@ -159,16 +150,16 @@
   * @exception SecurityException If the caller does not have permission to 
   *         perform this operation
   */ 
-public static PasswordAuthentication
-requestPasswordAuthentication(InetAddress addr, int port, String protocol,
+  public static PasswordAuthentication 
+    requestPasswordAuthentication(InetAddress addr, int port, String protocol,
                               String prompt, String scheme) 
   throws SecurityException
-{
+  {
   return(requestPasswordAuthentication (null, addr, port, protocol,
 					prompt, scheme));
-}
+  }
 
-/**
+  /**
   * This method is called whenever a username and password for a given
   * network operation is required.  First, a security check is made to see
   * if the caller has the "requestPasswordAuthentication"
@@ -196,141 +187,123 @@
   *
   * @since 1.4
   */
-public static PasswordAuthentication
-requestPasswordAuthentication(String host, InetAddress addr, int port,
+  public static PasswordAuthentication
+    requestPasswordAuthentication(String host, InetAddress addr, int port,
 		              String protocol, String prompt, String scheme)
   throws SecurityException
-{
+  {
   SecurityManager sm = System.getSecurityManager();
   if (sm != null)
     sm.checkPermission(new NetPermission("requestPasswordAuthentication"));
 
-  if (default_authenticator == null)
+    if (defaultAuthenticator == null)
     return(null);
 
-  default_authenticator.host = host;
-  default_authenticator.addr = addr;
-  default_authenticator.port = port;
-  default_authenticator.protocol = protocol;
-  default_authenticator.prompt = prompt;
-  default_authenticator.scheme = scheme;
-
-  return(default_authenticator.getPasswordAuthentication());
-}
-
-/**
- *  Returns the hostname of the host or proxy requesting authorization,
- *  or null if not available.
- *
- *  @since 1.4
- */
-protected final String getRequestingHost()
-{
-  return(host);
-}
+    defaultAuthenticator.host = host;
+    defaultAuthenticator.addr = addr;
+    defaultAuthenticator.port = port;
+    defaultAuthenticator.protocol = protocol;
+    defaultAuthenticator.prompt = prompt;
+    defaultAuthenticator.scheme = scheme;
 
-/*************************************************************************/
+    return(defaultAuthenticator.getPasswordAuthentication());
+  }
 
-/*
+  /*
  * Constructors
  */
 
-/**
+  /**
   * Default, no-argument constructor for subclasses to call.
   */
-public
-Authenticator()
-{
-}
-
-/*************************************************************************/
+  public Authenticator()
+  {
+  }
 
-/*
+  /*
  * Instance Methods
  */
 
-/**
+  /**
   * This method returns the address of the site that is requesting
   * authentication.
   *
-  * @return The requesting site
+    * @return The requesting site's address
   */
-protected final InetAddress
-getRequestingSite()
-{
+  protected final InetAddress getRequestingSite()
+  {
   return(addr);
-}
+  }
 
-/*************************************************************************/
+  /**
+   * Returns the hostname of the host or proxy requesting authorization,
+   * or <code>null</code> if not available.
+   *
+   * @return The name of the host requesting authentication, or
+   * </code>null</code> if it is not available.
+   *
+   * @since 1.4
+   */
+  protected final String getRequestingHost()
+  {
+    return(host);
+  }
 
-/**
+  /**
   * This method returns the port of the site that is requesting 
   * authentication.
   *
   * @return The requesting port
   */
-protected final int
-getRequestingPort()
-{
+  protected final int getRequestingPort()
+  {
   return(port);
-}
-
-/*************************************************************************/
+  }
 
-/**
+  /**
   * This method returns the requesting protocol of the operation that is
   * requesting authentication
   *
   * @return The requesting protocol
   */
-protected final String
-getRequestingProtocol()
-{
+  protected final String getRequestingProtocol()
+  {
   return(protocol);
-}
+  }
 
-/*************************************************************************/
-
-/**
+  /**
   * Returns the prompt that should be used when requesting authentication 
   * information from the user
   * 
   * @return The user prompt
   */
-protected final String
-getRequestingPrompt()
-{
+  protected final String getRequestingPrompt()
+  {
   return(prompt);
-}
+  }
 
-/*************************************************************************/
-
-/**
+  /**
   * This method returns the authentication scheme in use
   *
   * @return The authentication scheme
   */
-protected final String
-getRequestingScheme()
-{
+  protected final String getRequestingScheme()
+  {
   return(scheme);
-}
+  }
 
-/*************************************************************************/
-
-/**
+  /**
   * This method is called whenever a request for authentication is made.  It
   * can call the other getXXX methods to determine the information relevant
   * to this request.  Subclasses should override this method, which returns
   * <code>null</code> by default.
   *
-  * @return The PasswordAuthentication information
+    * @return The <code>PasswordAuthentication</code> information
   */
-protected PasswordAuthentication
-getPasswordAuthentication()
-{
+  protected PasswordAuthentication getPasswordAuthentication()
+  {
   return(null);
-}
+  }
 
 } // class Authenticator
 
Index: java/net/ContentHandler.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/ContentHandler.java,v
retrieving revision 1.6
diff -u -b -B -r1.6 ContentHandler.java
--- java/net/ContentHandler.java	21 Aug 2002 05:34:45 -0000	1.6
+++ java/net/ContentHandler.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* ContentHandler.java -- Abstract class for handling content from URL's
-   Copyright (C) 1998, 1999 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -59,21 +59,22 @@
   */
 public abstract class ContentHandler
 {
-
-/*************************************************************************/
-
-/*
+  /*
  * Constructors
  */
 
-/**
+  /**
   * Default, no-argument constructor.
   */
-public ContentHandler() { }
+  public ContentHandler() 
+  { 
+  }
 
-/*************************************************************************/
+  /*
+   * Instance Methods
+   */
 
-/**
+  /**
   * This method reads from the <code>InputStream</code> of the passed in URL 
   * connection and uses the data downloaded to create an <code>Object</code> 
   * represening the content.  For example, if the URL is pointing to a GIF 
@@ -86,29 +87,32 @@
   *
   * @exception IOException If an error occurs
   */
-public abstract Object getContent(URLConnection urlc) throws IOException;
+  public abstract Object getContent(URLConnection urlc) 
+    throws IOException;
 
-/*************************************************************************/
-
-/**
+  /**
   * This method reads from the <code>InputStream</code> of the passed in URL
   * connection and uses the data downloaded to create an <code>Object</code>
   * represening the content.  For example, if the URL is pointing to a GIF 
   * file, this method might return an <code>Image</code> object.  This method 
-  * must be implemented by subclasses. If the object doesnt match any type in
-  * classes it returns null.
+    * must be implemented by subclasses.  This method uses the list of
+    * supplied classes as candidate types.  If the data read doesn't match 
+    * any of the supplied type, <code>null</code> is returned.
   *
   * @param urlc A <code>URLConnection</code> object to read data from.
+    * @param classes An array of types of objects that are candidate types
+    * for the data to be read.
   *
-  * @return An object representing the data read
+    * @return An object representing the data read, or <code>null</code>
+    * if the data does not match any of the candidate types.
   *
   * @exception IOException If an error occurs
   *
   * @since 1.3
   */
-public Object getContent(URLConnection urlc, Class[] classes)
+  public Object getContent(URLConnection urlc, Class[] classes)
   throws IOException
-{
+  {
   Object obj = getContent (urlc);
 
   for (int i = 0; i < classes.length; i++)
@@ -118,6 +122,6 @@
     }
 
   return null;
-}
+  }
 
 } // class ContentHandler
Index: java/net/DatagramSocket.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/DatagramSocket.java,v
retrieving revision 1.23
diff -u -b -B -r1.23 DatagramSocket.java
--- java/net/DatagramSocket.java	17 Mar 2003 15:31:33 -0000	1.23
+++ java/net/DatagramSocket.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* DatagramSocket.java -- A class to model UDP sockets
-   Copyright (C) 1998, 1999, 2000, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2002, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -94,9 +94,11 @@
   private boolean closed = false;
 
   /**
-   * Creates a DatagramSocket from a specified DatagramSocketImpl instance
+   * Creates a <code>DatagramSocket</code> from a specified 
+   * <code>DatagramSocketImpl</code> instance
    *
-   * @param impl The DatagramSocketImpl the socket will be created from
+   * @param impl The <code>DatagramSocketImpl</code> the socket will be 
+   * created from
    * 
    * @since 1.4
    */
@@ -113,7 +115,7 @@
    *
    * @exception SocketException If an error occurs.
    * @exception SecurityException If a security manager exists and
-   * its checkListen method doesn't allow the operation.
+   * its <code>checkListen</code> method doesn't allow the operation.
    */
   public DatagramSocket() throws SocketException
   {
@@ -127,7 +129,7 @@
    * @param port The local port number to bind to.
    *
    * @exception SecurityException If a security manager exists and its
-   * checkListen method doesn't allow the operation.
+   * <code>checkListen</code> method doesn't allow the operation.
    * @exception SocketException If an error occurs.
    */
   public DatagramSocket(int port) throws SocketException
@@ -190,7 +192,7 @@
    * @param laddr The local address to bind to.
    *
    * @exception SecurityException If a security manager exists and its
-   * checkListen method doesn't allow the operation.
+   * <code>checkListen</code> method doesn't allow the operation.
    * @exception SocketException If an error occurs.
    *
    * @since 1.4
Index: java/net/DatagramSocketImplFactory.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/DatagramSocketImplFactory.java,v
retrieving revision 1.1
diff -u -b -B -r1.1 DatagramSocketImplFactory.java
--- java/net/DatagramSocketImplFactory.java	28 Aug 2002 19:23:50 -0000	1.1
+++ java/net/DatagramSocketImplFactory.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* DatagramSocketImplFactory.java
-   Copyright (C) 2002 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -42,7 +42,8 @@
   */
 
 /**
-  * This interface defines one method which returns a DatagramSocketImpl object.
+  * This interface defines one method which returns a 
+  * <code>DatagramSocketImpl</code> object.
   * This should not be needed by ordinary applications.
   *
   * @author Michael Koch <konqueror@gmx.de>
@@ -55,5 +56,5 @@
    *
    * @return A DatagramSocketImpl object
    */
-  DatagramSocketImpl createDatagramSocketImpl();
+  public DatagramSocketImpl createDatagramSocketImpl();
 } // interface DatagramSocketImplFactory
Index: java/net/FileNameMap.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/FileNameMap.java,v
retrieving revision 1.6
diff -u -b -B -r1.6 FileNameMap.java
--- java/net/FileNameMap.java	27 Aug 2002 17:47:26 -0000	1.6
+++ java/net/FileNameMap.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* FileNameMap.java -- Maps filenames to MIME types
-   Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -54,7 +54,7 @@
   */
 public interface FileNameMap
 {
-/**
+  /**
   * This method is passed a filename and is responsible for determining
   * the appropriate MIME type for that file.
   *
@@ -62,8 +62,7 @@
   *
   * @return The MIME type for the filename passed in.
   */
-String
-getContentTypeFor(String filename);
+  public String getContentTypeFor(String filename);
 
 } // interface FileNameMap
 
Index: java/net/SocketImplFactory.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/SocketImplFactory.java,v
retrieving revision 1.5
diff -u -b -B -r1.5 SocketImplFactory.java
--- java/net/SocketImplFactory.java	22 Jan 2002 22:40:23 -0000	1.5
+++ java/net/SocketImplFactory.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* SocketImplFactory.java -- Interface to create a SocketImpl object
-   Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -43,21 +43,20 @@
   */
 
 /**
-  * This interface defines one method which returns a SocketImpl object.
-  * This should not be needed by ordinary applications.
+  * This interface defines one method which returns a <code>SocketImpl</code>
+  * object.  This should not be needed by ordinary applications.
   *
   * @author Aaron M. Renn (arenn@urbanophile.com)
   * @author Per Bothner <bothner@cygnus.com>
   */
 public interface SocketImplFactory
 {
-/**
-  * This method returns an instance of the SocketImpl object
+  /**
+    * This method returns an instance of the <code>SocketImpl</code> object
   *
-  * @return A SocketImpl object
+    * @return A <code>SocketImpl</code> object
   */
-SocketImpl
-createSocketImpl();
+  public SocketImpl createSocketImpl();
 
 } // interface SocketImplFactory
 
Index: java/net/URLStreamHandlerFactory.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/URLStreamHandlerFactory.java,v
retrieving revision 1.5
diff -u -b -B -r1.5 URLStreamHandlerFactory.java
--- java/net/URLStreamHandlerFactory.java	22 Jan 2002 22:40:23 -0000	1.5
+++ java/net/URLStreamHandlerFactory.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* URLStreamHandlerFactory.java -- Maps protocols to URLStreamHandlers
-   Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -46,23 +46,22 @@
 /**
  * This interface contains one method which maps the protocol portion of
  * a URL (eg, "http" in "http://www.urbanophile.com/arenn/";) to a 
- * URLStreamHandler object.
+ * <code>URLStreamHandler</code> object.
  *
  * @author Aaron M. Renn (arenn@urbanophile.com)
  * @author Warren Levy <warrenl@cygnus.com>
  */
 public interface URLStreamHandlerFactory
 {
-/**
-  * This method maps the protocol portion of a URL to a URLStreamHandler
-  * object.
+  /**
+    * This method maps the protocol portion of a URL to a 
+    * <code>URLStreamHandler</code> object.
   *
   * @param protocol The protocol name to map ("http", "ftp", etc).
   *
-  * @return The URLStreamHandler for the specified protocol
+    * @return The <code>URLStreamHandler</code> for the specified protocol
   */
-URLStreamHandler
-createURLStreamHandler(String protocol);
+  public URLStreamHandler createURLStreamHandler(String protocol);
 
 } // interface URLStreamHandlerFactory
 

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: java/net/ContentHandlerFactory.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/ContentHandlerFactory.java,v
retrieving revision 1.5
diff -u -b -B -r1.5 ContentHandlerFactory.java
--- java/net/ContentHandlerFactory.java	22 Jan 2002 22:40:23 -0000	1.5
+++ java/net/ContentHandlerFactory.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,5 @@
 /* ContentHandlerFactory.java -- Interface for creating content handlers
-   Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -45,25 +45,24 @@
  */
 
 /**
-  * This interface maps MIME types to ContentHandler objects.  It consists
-  * of one method that, when passed a MIME type, returns a handler for that
-  * type.
+  * This interface maps MIME types to <code>ContentHandler</code> objects.  
+  * It consists of one method that, when passed a MIME type, returns a 
+  * handler for that type.
   *
   * @author Aaron M. Renn (arenn@urbanophile.com)
   * @author Warren Levy <warrenl@cygnus.com>
   */
 public interface ContentHandlerFactory
 {
-/**
+  /**
   * This method is passed a MIME type as a string and is responsible for
-  * returning the appropriate ContentType object.
+    * returning the appropriate <code>ContentHandler</code> object.
   *
   * @param mime_type The MIME type to map to a ContentHandler
   *
-  * @return The ContentHandler for the passed in MIME type
+    * @return The <code>ContentHandler</code> for the passed in MIME type
   */
-ContentHandler
-createContentHandler(String mime_type);
+  public ContentHandler createContentHandler(String mimeType);
 
 } // interface ContentHandlerFactory
 
@@ -45,25 +45,24 @@
   *
-  * @param mime_type The MIME type to map to a ContentHandler
+    * @param mimeType The MIME type to map to a <code>ContentHandler</code>
   *
Index: java/net/DatagramSocketImpl.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/DatagramSocketImpl.java,v
retrieving revision 1.12
diff -u -b -B -r1.12 DatagramSocketImpl.java
--- java/net/DatagramSocketImpl.java	25 Sep 2002 05:05:06 -0000	1.12
+++ java/net/DatagramSocketImpl.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,6 @@
 /* DatagramSocketImpl.java -- Abstract class for UDP socket implementations
-   Copyright (C) 1998, 1999 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999 2000, 2001, 
+                 2002, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -102,8 +103,8 @@
    * Takes a peek at the next packet received in order to retrieve the
    * address of the sender
    *
-   * @param i The InetAddress to fill in with the information about the
-   *          sender if the next packet
+   * @param i The <code>InetAddress</code> to fill in with the information 
+   *          about the sender if the next packet
    *
    * @return The port number of the sender of the packet
    *
@@ -118,7 +119,7 @@
    * Takes a peek at the next packet received.  This packet is not consumed.
    * With the next peekData/receive operation this packet will be read again.
    * 
-   * @param p The DatagramPacket to fill in with the data sent.
+   * @param p The <code>DatagramPacket</code> to fill in with the data sent.
    *
    * @return The port number of the sender of the packet.
    * 
@@ -147,7 +148,7 @@
   /**
    * Receives a packet of data from the network  Will block until a packet
    * arrives.  The packet info in populated into the passed in
-   * DatagramPacket object.
+   * <code>DatagramPacket</code> object.
    *
    * @param p A place to store the incoming packet.
    *
@@ -161,7 +162,7 @@
   /**
    * Connects the socket to a host specified by address and port.
    *
-   * @param address The InetAddress of the host to connect to
+   * @param address The <code>InetAddress</code> of the host to connect to
    * @param port The port number of the host to connect to
    *
    * @exception SocketException If an error occurs
@@ -288,26 +289,26 @@
    * Sets the specified option on a socket to the passed in object.  For
    * options that take an integer argument, the passed in object is an
    * <code>Integer</code>.  For options that are set to on or off, the
    * value passed will be a <code>Boolean</code>.   The <code>option_id</code>
    * parameter is one of the defined constants in the superinterface.
    *
    * @param option_id The identifier of the option
    * @param val The value to set the option to
    *
    * @exception SocketException If an error occurs
    * @XXX This redeclaration from SocketOptions is a workaround to a gcj bug.
    */
-  public abstract void setOption(int option_id, Object val)
+  public abstract void setOption(int optionId, Object val)
     throws SocketException;
 
   /**
    * Returns the current setting of the specified option.  The
    * <code>Object</code> returned will be an <code>Integer</code> for options
    * that have integer values.  For options that are set to on or off, a
    * <code>Boolean</code> will be returned.   The <code>option_id</code>
    * is one of the defined constants in the superinterface.
    *
    * @param option_id The option identifier
    *
    * @return The current value of the option
    *
@@ -288,26 +289,26 @@
    * options that take an integer argument, the passed in object is an
    * <code>Integer</code>.  For options that are set to on or off, the
-   * value passed will be a <code>Boolean</code>.   The <code>option_id</code>
+   * value passed will be a <code>Boolean</code>.   The <code>optionId</code>
    * parameter is one of the defined constants in the superinterface.
    *
@@ -288,26 +289,26 @@
    * parameter is one of the defined constants in the superinterface.
    *
-   * @param option_id The identifier of the option
+   * @param optionId The identifier of the option
    * @param val The value to set the option to
    *
@@ -288,26 +289,26 @@
    * <code>Object</code> returned will be an <code>Integer</code> for options
    * that have integer values.  For options that are set to on or off, a
-   * <code>Boolean</code> will be returned.   The <code>option_id</code>
+   * <code>Boolean</code> will be returned.   The <code>optionId</code>
    * is one of the defined constants in the superinterface.
    *
@@ -288,26 +289,26 @@
    * is one of the defined constants in the superinterface.
    *
-   * @param option_id The option identifier
+   * @param optionId The option identifier
    *
    * @return The current value of the option
Index: java/net/SocketOptions.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/SocketOptions.java,v
retrieving revision 1.10
diff -u -b -B -r1.10 SocketOptions.java
--- java/net/SocketOptions.java	3 Oct 2002 14:30:48 -0000	1.10
+++ java/net/SocketOptions.java	25 May 2003 11:28:33 -0000
@@ -1,5 +1,6 @@
 /* SocketOptions.java -- Implements options for sockets (duh!)
-   Copyright (C) 1998, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 
+                 2002, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -138,30 +139,30 @@
    * Sets the specified option on a socket to the passed in object.  For
    * options that take an integer argument, the passed in object is an
    * <code>Integer</code>.  For options that are set to on or off, the
    * value passed will be a <code>Boolean</code>.   The <code>option_id</code>
    * parameter is one of the defined constants in this interface.
    *
    * @param option_id The identifier of the option
    * @param val The value to set the option to
    *
    * @exception SocketException If an error occurs
    */
-  void setOption(int option_id, Object val) throws SocketException;
+  void setOption(int optionId, Object val) throws SocketException;
 
   /**
    * Returns the current setting of the specified option.  The
    * <code>Object</code> returned will be an <code>Integer</code> for options
    * that have integer values.  For options that are set to on or off, a
    * <code>Boolean</code> will be returned.   The <code>option_id</code>
    * is one of the defined constants in this interface.
    *
    * @param option_id The option identifier
    *
    * @return The current value of the option
    *
    * @exception SocketException If an error occurs
    */
-  Object getOption(int option_id) throws SocketException;
+  Object getOption(int optionId) throws SocketException;
 
 } // interface SocketOptions
 
@@ -138,30 +139,30 @@
    * options that take an integer argument, the passed in object is an
    * <code>Integer</code>.  For options that are set to on or off, the
-   * value passed will be a <code>Boolean</code>.   The <code>option_id</code>
+   * value passed will be a <code>Boolean</code>.   The <code>optionId</code>
    * parameter is one of the defined constants in this interface.
    *
@@ -138,30 +139,30 @@
    * parameter is one of the defined constants in this interface.
    *
-   * @param option_id The identifier of the option
+   * @param optionId The identifier of the option
    * @param val The value to set the option to
    *
@@ -138,30 +139,30 @@
    * <code>Object</code> returned will be an <code>Integer</code> for options
    * that have integer values.  For options that are set to on or off, a
-   * <code>Boolean</code> will be returned.   The <code>option_id</code>
-   * is one of the defined constants in this interface.
+   * <code>Boolean</code> will be returned.   The <code>optionId</code>
+   * parameter is one of the defined constants in this interface.
    *
@@ -138,30 +139,30 @@
    *
-   * @param option_id The option identifier
+   * @param optionId The option identifier
    *
    * @return The current value of the option